Revision: 468
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=468&view=rev
Author: frlan
Date: 2009-02-10 22:55:07 +0000 (Tue, 10 Feb 2009)
Log Message:
-----------
GeanyVC: Make some more strings translatable and some more minor updates arround
Modified Paths:
--------------
trunk/geanyvc/geanyvc.c
trunk/geanyvc/po/de.po
Modified: trunk/geanyvc/geanyvc.c
===================================================================
--- trunk/geanyvc/po/de.po 2009-02-09 14:56:49 UTC (rev 467)
+++ trunk/geanyvc/po/de.po 2009-02-10 22:55:07 UTC (rev 468)
@@ -8,8 +8,8 @@
msgstr ""
"Project-Id-Version: geanyvc 0.5\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2009-02-08 22:13+0100\n"
-"PO-Revision-Date: 2009-02-08 22:08+0100\n"
+"POT-Creation-Date: 2009-02-10 23:47+0100\n"
+"PO-Revision-Date: 2009-02-10 23:48+0100\n"
"Last-Translator: Frank Lanitz <frank(a)frank.uvena.de>\n"
"Language-Team: German <geany-i18n(a)uvena.de>\n"
"MIME-Version: 1.0\n"
@@ -32,8 +32,7 @@
msgid ""
"Yura Siamashka <yurand2(a)gmail.com>,\n"
"Frank Lanitz <frank(a)frank.uvena.de>"
-msgstr ""
-"Yura Siamashka <yurand2(a)gmail.com>, Frank Lanitz <frank(a)frank.uvena.de>"
+msgstr "Yura Siamashka <yurand2(a)gmail.com>, Frank Lanitz <frank(a)frank.uvena.de>"
#: ../geanyvc.c:407
msgid "Could not parse the output of command"
@@ -44,12 +43,14 @@
msgid "geanyvc: s_spawn_sync error: %s"
msgstr "geanyvc: s_spawn_sync error: %s"
-#: ../geanyvc.c:600 ../geanyvc.c:611
+#: ../geanyvc.c:600
+#: ../geanyvc.c:611
#, c-format
msgid "geanyvc: vcdiff_file_activated: Unable to rename '%s' to '%s'"
msgstr "geanyvc: vcdiff_file_activated: Kann »%s« nicht in »%s« umbenennen."
-#: ../geanyvc.c:637 ../geanyvc.c:686
+#: ../geanyvc.c:637
+#: ../geanyvc.c:686
msgid "No changes were made."
msgstr "Es wurden keine Änderungen vorgenommen."
@@ -57,7 +58,8 @@
msgid "No history avaible"
msgstr "Keine Historie verfügbar"
-#: ../geanyvc.c:905 ../geanyvc.c:913
+#: ../geanyvc.c:905
+#: ../geanyvc.c:913
#, c-format
msgid "Do you really want to revert: %s?"
msgstr "Möchten Sie wirklich »%s« zurücksetzen?"
@@ -76,6 +78,18 @@
msgid "Do you really want to update?"
msgstr "Möchten Sie wirklich »%s« aktualisieren?"
+#: ../geanyvc.c:1152
+msgid "Commit Y/N"
+msgstr "Übertragen"
+
+#: ../geanyvc.c:1162
+msgid "Status"
+msgstr "Status"
+
+#: ../geanyvc.c:1169
+msgid "Path"
+msgstr "Pfad"
+
#: ../geanyvc.c:1231
msgid "Commit"
msgstr "Übertragen"
@@ -85,7 +99,8 @@
msgstr "<b>Commitnachricht:</b>"
#. Commit all changes
-#: ../geanyvc.c:1315 ../geanyvc.c:2171
+#: ../geanyvc.c:1315
+#: ../geanyvc.c:2171
msgid "_Commit"
msgstr "Ü_bertragen"
@@ -100,12 +115,8 @@
#: ../geanyvc.c:1443
#, c-format
-msgid ""
-"Error while setting up language for spellchecking. Please check "
-"configuration. Error message was: %s"
-msgstr ""
-"Fehler beim Auswählen der Sprache für die Rechtschreibprüfung. Bitte "
-"überprüfen Sie Ihre Konfiguration. Fehlermeldung: %s"
+msgid "Error while setting up language for spellchecking. Please check configuration. Error message was: %s"
+msgstr "Fehler beim Auswählen der Sprache für die Rechtschreibprüfung. Bitte überprüfen Sie Ihre Konfiguration. Fehlermeldung: %s"
#: ../geanyvc.c:1674
msgid "Plugin configuration directory could not be created."
@@ -116,15 +127,8 @@
msgstr "Markiere vom Plugin erstelle Dokumente als geändert"
#: ../geanyvc.c:1710
-msgid ""
-"If this option is activated, every new by the VC-plugin created document tab "
-"will be marked as changed. Even this option is useful in some cases, it "
-"could cause a big number of annoying \"Do you want to save\"-dialogs."
-msgstr ""
-"Wenn diese Option aktiviert ist, werden alle Dokumente die durch das Plugin "
-"erzeugt werden als geändert markiert, sodass z.B. beim Schließen der Datei "
-"der Speichern Dialog geöffnet wird. Auch wenn diese Option von Zeit zu Zeit "
-"sehr nützlich sein kann, kann Sie ab und an einfach nur stören."
+msgid "If this option is activated, every new by the VC-plugin created document tab will be marked as changed. Even this option is useful in some cases, it could cause a big number of annoying \"Do you want to save\"-dialogs."
+msgstr "Wenn diese Option aktiviert ist, werden alle Dokumente die durch das Plugin erzeugt werden als geändert markiert, sodass z.B. beim Schließen der Datei der Speichern Dialog geöffnet wird. Auch wenn diese Option von Zeit zu Zeit sehr nützlich sein kann, kann Sie ab und an einfach nur stören."
#: ../geanyvc.c:1718
msgid "Confirm adding new files to a VCS"
@@ -132,9 +136,7 @@
#: ../geanyvc.c:1721
msgid "Shows a confirmation dialog on adding a new (created) file to VCS."
-msgstr ""
-"Zeigt einen Bestätigungsdialog wenn Dateien zu einem Versionskontrollsystem "
-"hinzugefügt werden sollen."
+msgstr "Zeigt einen Bestätigungsdialog wenn Dateien zu einem Versionskontrollsystem hinzugefügt werden sollen."
#: ../geanyvc.c:1728
msgid "Maximize commit dialog"
@@ -187,7 +189,9 @@
#. Diff of current file
#. Diff of the current dir
#. Complete diff of base directory
-#: ../geanyvc.c:1928 ../geanyvc.c:2012 ../geanyvc.c:2053
+#: ../geanyvc.c:1928
+#: ../geanyvc.c:2012
+#: ../geanyvc.c:2053
msgid "_Diff"
msgstr "_Unterschiede anzeigen"
@@ -198,15 +202,15 @@
#. Revert current file
#. Revert current dir
#. Revert everything
-#: ../geanyvc.c:1937 ../geanyvc.c:2021 ../geanyvc.c:2062
+#: ../geanyvc.c:1937
+#: ../geanyvc.c:2021
+#: ../geanyvc.c:2062
msgid "_Revert"
msgstr "_Zurücksetzen"
#: ../geanyvc.c:1940
msgid "Restore pristine working copy file (undo local edits)."
-msgstr ""
-"Stellt den ursprünglichen Zustand der Datei wieder her (verwirft lokale "
-"Änderungen)."
+msgstr "Stellt den ursprünglichen Zustand der Datei wieder her (verwirft lokale Änderungen)."
#. Blame for current file
#: ../geanyvc.c:1950
@@ -220,7 +224,9 @@
#. History/log of current file
#. History/log of the current dir
#. Complete History/Log of base directory
-#: ../geanyvc.c:1961 ../geanyvc.c:2032 ../geanyvc.c:2074
+#: ../geanyvc.c:1961
+#: ../geanyvc.c:2032
+#: ../geanyvc.c:2074
msgid "_History"
msgstr "_Versionsgeschichte"
@@ -265,9 +271,7 @@
#: ../geanyvc.c:2024
msgid "Restore original files in the current folder (undo local edits)."
-msgstr ""
-"Stellt den ursprünglichen Zustand der Datei wieder her (verwirft lokale "
-"Änderungen)."
+msgstr "Stellt den ursprünglichen Zustand der Datei wieder her (verwirft lokale Änderungen)."
#: ../geanyvc.c:2035
msgid "Shows the log of the current directory"
@@ -353,33 +357,24 @@
#~ msgid "Current _File"
#~ msgstr "_Aktuelle Datei"
-
#~ msgid "Current _Basedirectory"
#~ msgstr "Aktuelles _Basisverzeichnis"
-
#~ msgid "Diff From Current File"
#~ msgstr "Diff von der aktuellen Datei"
-
#~ msgid "Diff From Current Directory"
#~ msgstr "Diff vom aktuellen Verzeichnis"
-
#~ msgid "Diff From Base Directory"
#~ msgstr "Diff vom Grundverzeichnis"
-
#~ msgid "Blame From Current File"
#~ msgstr "Blame von aktueller Datei"
-
#~ msgid "Remove File"
#~ msgstr "Datei entfernen"
-
#~ msgid "Diff From Current Project"
#~ msgstr "Diff vom aktuellen Projekt"
-
#~ msgid "Make a diff from the current project's base path"
#~ msgstr "Erstellt ein Diff für das aktuell geöffnete Projekt."
-
#~ msgid "Log Of Current Project"
#~ msgstr "Historie vom aktuellen Projekt"
-
#~ msgid "Shows the log of the current project"
#~ msgstr "Zeigt die Versionshistorie vom aktuellen Projekt."
+
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 466
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=466&view=rev
Author: frlan
Date: 2009-02-08 21:21:04 +0000 (Sun, 08 Feb 2009)
Log Message:
-----------
GeanyVC: Update of German translation
Modified Paths:
--------------
trunk/geanyvc/po/ChangeLog
trunk/geanyvc/po/de.po
Modified: trunk/geanyvc/po/ChangeLog
===================================================================
--- trunk/geanyvc/po/ChangeLog 2009-02-08 21:04:50 UTC (rev 465)
+++ trunk/geanyvc/po/ChangeLog 2009-02-08 21:21:04 UTC (rev 466)
@@ -1,3 +1,8 @@
+2009-02-08 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+
+ * de.po: Update of German translation
+
+
2009-01-27 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
* de.po: Translation of new strings.
Modified: trunk/geanyvc/po/de.po
===================================================================
--- trunk/geanyvc/po/de.po 2009-02-08 21:04:50 UTC (rev 465)
+++ trunk/geanyvc/po/de.po 2009-02-08 21:21:04 UTC (rev 466)
@@ -1,15 +1,15 @@
# German translations for PACKAGE package.
# Copyright (C) 2008 THE PACKAGE'S COPYRIGHT HOLDER
# This file is distributed under the same license as the PACKAGE package.
-# Frank Lanitz <frank(a)frank.uvena.de>, 2008.
-# Enrico Tröger <enrico.troeger(a)uvena.de>, 2008.
+# Frank Lanitz <frank(a)frank.uvena.de>, 2008-2009.
+# Enrico Tröger <enrico.troeger(a)uvena.de>, 2008-2009.
#
msgid ""
msgstr ""
-"Project-Id-Version: geanyvc 0.4\n"
+"Project-Id-Version: geanyvc 0.5\n"
"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2009-01-27 23:32+0100\n"
-"PO-Revision-Date: 2009-01-27 23:37+0100\n"
+"POT-Creation-Date: 2009-02-08 22:13+0100\n"
+"PO-Revision-Date: 2009-02-08 22:08+0100\n"
"Last-Translator: Frank Lanitz <frank(a)frank.uvena.de>\n"
"Language-Team: German <geany-i18n(a)uvena.de>\n"
"MIME-Version: 1.0\n"
@@ -35,70 +35,70 @@
msgstr ""
"Yura Siamashka <yurand2(a)gmail.com>, Frank Lanitz <frank(a)frank.uvena.de>"
-#: ../geanyvc.c:402
+#: ../geanyvc.c:407
msgid "Could not parse the output of command"
msgstr "Kann die Ausgabe des Befehls nicht einlesen."
-#: ../geanyvc.c:462
+#: ../geanyvc.c:466
#, c-format
msgid "geanyvc: s_spawn_sync error: %s"
msgstr "geanyvc: s_spawn_sync error: %s"
-#: ../geanyvc.c:596 ../geanyvc.c:607
+#: ../geanyvc.c:600 ../geanyvc.c:611
#, c-format
msgid "geanyvc: vcdiff_file_activated: Unable to rename '%s' to '%s'"
msgstr "geanyvc: vcdiff_file_activated: Kann »%s« nicht in »%s« umbenennen."
-#: ../geanyvc.c:633 ../geanyvc.c:668 ../geanyvc.c:712
+#: ../geanyvc.c:637 ../geanyvc.c:686
msgid "No changes were made."
msgstr "Es wurden keine Änderungen vorgenommen."
-#: ../geanyvc.c:738
+#: ../geanyvc.c:712
msgid "No history avaible"
msgstr "Keine Historie verfügbar"
-#: ../geanyvc.c:900
+#: ../geanyvc.c:905 ../geanyvc.c:913
#, c-format
msgid "Do you really want to revert: %s?"
msgstr "Möchten Sie wirklich »%s« zurücksetzen?"
-#: ../geanyvc.c:908
+#: ../geanyvc.c:921
#, c-format
msgid "Do you really want to add: %s?"
msgstr "Möchten Sie wirklich »%s« hinzufügen?"
-#: ../geanyvc.c:915
+#: ../geanyvc.c:928
#, c-format
msgid "Do you really want to remove: %s?"
msgstr "Möchten Sie wirklich »%s« entfernen?"
-#: ../geanyvc.c:939
+#: ../geanyvc.c:952
msgid "Do you really want to update?"
msgstr "Möchten Sie wirklich »%s« aktualisieren?"
-#: ../geanyvc.c:1218
+#: ../geanyvc.c:1231
msgid "Commit"
msgstr "Übertragen"
-#: ../geanyvc.c:1289
+#: ../geanyvc.c:1302
msgid "<b>Commit message:</b>"
msgstr "<b>Commitnachricht:</b>"
#. Commit all changes
-#: ../geanyvc.c:1302 ../geanyvc.c:2109
+#: ../geanyvc.c:1315 ../geanyvc.c:2171
msgid "_Commit"
msgstr "Ü_bertragen"
-#: ../geanyvc.c:1372
+#: ../geanyvc.c:1385
msgid "Nothing to commit."
msgstr "Nichts zum Übertragen."
-#: ../geanyvc.c:1418
+#: ../geanyvc.c:1431
#, c-format
msgid "Error initializing spell checking: %s"
msgstr "Fehler beim Initialisieren der Rechtschreibprüfung: %s"
-#: ../geanyvc.c:1430
+#: ../geanyvc.c:1443
#, c-format
msgid ""
"Error while setting up language for spellchecking. Please check "
@@ -107,15 +107,15 @@
"Fehler beim Auswählen der Sprache für die Rechtschreibprüfung. Bitte "
"überprüfen Sie Ihre Konfiguration. Fehlermeldung: %s"
-#: ../geanyvc.c:1642
+#: ../geanyvc.c:1674
msgid "Plugin configuration directory could not be created."
msgstr "Plugin-Konfigurationsverzeichnis konnte nicht erstellt werden."
-#: ../geanyvc.c:1675
+#: ../geanyvc.c:1707
msgid "Set Changed-flag for document tabs created by the plugin"
msgstr "Markiere vom Plugin erstelle Dokumente als geändert"
-#: ../geanyvc.c:1678
+#: ../geanyvc.c:1710
msgid ""
"If this option is activated, every new by the VC-plugin created document tab "
"will be marked as changed. Even this option is useful in some cases, it "
@@ -126,202 +126,237 @@
"der Speichern Dialog geöffnet wird. Auch wenn diese Option von Zeit zu Zeit "
"sehr nützlich sein kann, kann Sie ab und an einfach nur stören."
-#: ../geanyvc.c:1686
+#: ../geanyvc.c:1718
msgid "Confirm adding new files to a VCS"
msgstr "Hinzufügen von Dateien zur Versionsverwaltung immer bestätigen"
-#: ../geanyvc.c:1689
+#: ../geanyvc.c:1721
msgid "Shows a confirmation dialog on adding a new (created) file to VCS."
msgstr ""
"Zeigt einen Bestätigungsdialog wenn Dateien zu einem Versionskontrollsystem "
"hinzugefügt werden sollen."
-#: ../geanyvc.c:1696
+#: ../geanyvc.c:1728
msgid "Maximize commit dialog"
msgstr "Commit-Dialog maximieren"
-#: ../geanyvc.c:1697
+#: ../geanyvc.c:1729
msgid "Show commit dialog maximize."
msgstr "Commit-Dialog beim Anzeigen maximieren"
-#: ../geanyvc.c:1704
+#: ../geanyvc.c:1736
msgid "Use external diff viewer"
msgstr "Externes Diff-Programm benutzen"
-#: ../geanyvc.c:1706
+#: ../geanyvc.c:1738
msgid "Use external diff viewer for file diff."
msgstr "Externes Diff-Programm benutzen zum Vergleich von zwei Dateien."
-#: ../geanyvc.c:1712
+#: ../geanyvc.c:1744
msgid "Enable CVS"
msgstr "CVS aktivieren"
-#: ../geanyvc.c:1717
+#: ../geanyvc.c:1749
msgid "Enable GIT"
msgstr "GIT aktivieren"
-#: ../geanyvc.c:1722
+#: ../geanyvc.c:1754
msgid "Enable SVN"
msgstr "SVN aktivieren"
-#: ../geanyvc.c:1727
+#: ../geanyvc.c:1759
msgid "Enable SVK"
msgstr "SVK aktivieren"
-#: ../geanyvc.c:1732
+#: ../geanyvc.c:1764
msgid "Enable Bazaar"
msgstr "Bazaar aktivieren"
-#: ../geanyvc.c:1737
+#: ../geanyvc.c:1769
msgid "Enable Mercurial"
msgstr "Mercurial aktivieren"
-#: ../geanyvc.c:1743
+#: ../geanyvc.c:1775
msgid "Spellcheck language"
msgstr "Sprache"
-#: ../geanyvc.c:1892
-msgid "Current _File"
-msgstr "_Aktuelle Datei"
+#: ../geanyvc.c:1924
+msgid "_File"
+msgstr "_Datei"
#. Diff of current file
#. Diff of the current dir
#. Complete diff of base directory
-#: ../geanyvc.c:1896 ../geanyvc.c:1971 ../geanyvc.c:2002
+#: ../geanyvc.c:1928 ../geanyvc.c:2012 ../geanyvc.c:2053
msgid "_Diff"
-msgstr "_Unterscheide anzeigen"
+msgstr "_Unterschiede anzeigen"
-#: ../geanyvc.c:1899
+#: ../geanyvc.c:1931
msgid "Make a diff from the current active file"
msgstr "Erstellt ein Diff für die aktuelle Datei."
#. Revert current file
-#: ../geanyvc.c:1905
+#. Revert current dir
+#. Revert everything
+#: ../geanyvc.c:1937 ../geanyvc.c:2021 ../geanyvc.c:2062
msgid "_Revert"
msgstr "_Zurücksetzen"
-#: ../geanyvc.c:1908
+#: ../geanyvc.c:1940
msgid "Restore pristine working copy file (undo local edits)."
msgstr ""
"Stellt den ursprünglichen Zustand der Datei wieder her (verwirft lokale "
"Änderungen)."
#. Blame for current file
-#: ../geanyvc.c:1918
+#: ../geanyvc.c:1950
msgid "_Blame"
msgstr "Ä_nderungsverfolgung"
-#: ../geanyvc.c:1921
+#: ../geanyvc.c:1953
msgid "Shows the changes made at one file per revision and author."
msgstr "Zeigt alle Änderungen einer Datei nach Autor und Revision."
#. History/log of current file
#. History/log of the current dir
#. Complete History/Log of base directory
-#: ../geanyvc.c:1929 ../geanyvc.c:1981 ../geanyvc.c:2015
+#: ../geanyvc.c:1961 ../geanyvc.c:2032 ../geanyvc.c:2074
msgid "_History"
msgstr "_Versionsgeschichte"
-#: ../geanyvc.c:1932
+#: ../geanyvc.c:1964
msgid "Shows the log of the current file"
msgstr "Zeigt die Versionshistorie der aktuellen Datei an."
+#. base version of the current file
+#: ../geanyvc.c:1970
+msgid "_Original"
+msgstr "&Original"
+
+#: ../geanyvc.c:1973
+msgid "Shows the orignal of the current file"
+msgstr "Zeigt die unveränderte Datei an"
+
#. add current file
-#: ../geanyvc.c:1941
+#: ../geanyvc.c:1982
msgid "_Add to Version Control"
msgstr "Zur _Versionskontrolle hinzufügen"
-#: ../geanyvc.c:1943
+#: ../geanyvc.c:1984
msgid "Add file to repository."
msgstr "Fügt eine Datei zum Repositorium _hinzu."
-#. revert current file
-#: ../geanyvc.c:1949
+#. remove current file
+#: ../geanyvc.c:1990
msgid "_Remove from Version Control"
msgstr "Aus Versionskontrolle entfernen"
-#: ../geanyvc.c:1952
+#: ../geanyvc.c:1993
msgid "Remove file from repository."
msgstr "Entfernt eine Datei aus dem Repositorium."
-#: ../geanyvc.c:1968
-msgid "Current _Directory"
-msgstr "Aktueller _Dokumentenordner"
+#: ../geanyvc.c:2009
+msgid "_Directory"
+msgstr "_Verzeichnis"
-#: ../geanyvc.c:1974
+#: ../geanyvc.c:2015
msgid "Make a diff from the directory of the current active file"
msgstr "Erstellt ein Diff für das Verzeichnis der aktuellen Datei."
-#: ../geanyvc.c:1984
+#: ../geanyvc.c:2024
+msgid "Restore original files in the current folder (undo local edits)."
+msgstr ""
+"Stellt den ursprünglichen Zustand der Datei wieder her (verwirft lokale "
+"Änderungen)."
+
+#: ../geanyvc.c:2035
msgid "Shows the log of the current directory"
msgstr "Zeigt die Versionshistorie für das aktuelle Verzeichnis."
-#: ../geanyvc.c:1998
-msgid "Current _Basedirectory"
-msgstr "Aktuelles _Basisverzeichnis"
+#: ../geanyvc.c:2049
+msgid "_Base Directory"
+msgstr "&Basisordner"
-#: ../geanyvc.c:2005
+#: ../geanyvc.c:2056
msgid "Make a diff from the top VC directory"
msgstr "Erstellt ein Diff für die gesamte Arbeitskopie"
-#: ../geanyvc.c:2018
+#: ../geanyvc.c:2064
+msgid "Revert any local edits."
+msgstr "Alle lokalen Änderungen zurücksetzen"
+
+#: ../geanyvc.c:2077
msgid "Shows the log of the top VC directory"
msgstr "Zeigt die Versionsgeschichte für die gesamte Arbeitskopie"
-#: ../geanyvc.c:2032
+#: ../geanyvc.c:2091
msgid "Show diff of file"
msgstr "Diff von der aktuellen Datei"
-#: ../geanyvc.c:2035
+#: ../geanyvc.c:2093
msgid "Show diff of diretory"
msgstr "Diff vom aktuellen Verzeichnis"
-#: ../geanyvc.c:2037
+#: ../geanyvc.c:2095
msgid "Show diff of basedir"
msgstr "Diff vom Grundverzeichnis"
-#: ../geanyvc.c:2040
+#: ../geanyvc.c:2098
msgid "Commit changes"
msgstr "Änderungen übertragen"
-#: ../geanyvc.c:2042
+#: ../geanyvc.c:2100
msgid "Show status"
msgstr "Status der Arbeitskopie anzeigen"
-#: ../geanyvc.c:2044
-msgid "Revert changes"
+#: ../geanyvc.c:2102
+msgid "Revert single file"
msgstr "Änderungen verwerfen"
-#: ../geanyvc.c:2046
+#: ../geanyvc.c:2104
+msgid "Revert whole directory"
+msgstr "Verzeichnis zurücksetzen"
+
+#: ../geanyvc.c:2106
+msgid "Revert whole tree"
+msgstr ""
+
+#: ../geanyvc.c:2108
msgid "Update file"
msgstr "Datei aktualisieren"
-#: ../geanyvc.c:2071
+#: ../geanyvc.c:2133
msgid "_VC"
msgstr "_VC"
#. Status of basedir
-#: ../geanyvc.c:2091
+#: ../geanyvc.c:2153
msgid "_Status"
msgstr "_Status"
-#: ../geanyvc.c:2093
+#: ../geanyvc.c:2155
msgid "Show status."
msgstr "Zeigt den Status der Arbeitskopie."
#. complete update
-#: ../geanyvc.c:2100
+#: ../geanyvc.c:2162
msgid "Update"
msgstr "Aktualisieren"
-#: ../geanyvc.c:2102
+#: ../geanyvc.c:2164
msgid "Update from remote repositary."
msgstr "Aus dem Repository aktualisieren"
-#: ../geanyvc.c:2111
+#: ../geanyvc.c:2173
msgid "Commit changes."
msgstr "Änderungen übertragen."
+#~ msgid "Current _File"
+#~ msgstr "_Aktuelle Datei"
+
+#~ msgid "Current _Basedirectory"
+#~ msgstr "Aktuelles _Basisverzeichnis"
+
#~ msgid "Diff From Current File"
#~ msgstr "Diff von der aktuellen Datei"
@@ -334,12 +369,6 @@
#~ msgid "Blame From Current File"
#~ msgstr "Blame von aktueller Datei"
-#~ msgid "Log Of Base Directory"
-#~ msgstr "Historie vom aktuellen Grundverzeichnis"
-
-#~ msgid "_Add File"
-#~ msgstr "Datei _hinzufügen"
-
#~ msgid "Remove File"
#~ msgstr "Datei entfernen"
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 462
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=462&view=rev
Author: prublot
Date: 2009-02-08 14:24:34 +0000 (Sun, 08 Feb 2009)
Log Message:
-----------
patch of Enrico Tr?\195?\182ger about the localization, the German translation, ....
Modified Paths:
--------------
trunk/geany-mini-script/configure.in
trunk/geany-mini-script/po/de.po
trunk/geany-mini-script/po/en.po
trunk/geany-mini-script/po/fr.po
trunk/geany-mini-script/src/Makefile.am
trunk/geany-mini-script/src/gms.c
trunk/geany-mini-script/src/gms_gui.c
Modified: trunk/geany-mini-script/configure.in
===================================================================
--- trunk/geany-mini-script/configure.in 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/configure.in 2009-02-08 14:24:34 UTC (rev 462)
@@ -1,7 +1,7 @@
dnl Process this file with autoconf to produce a configure script.
-AC_INIT([gms], [0.3], [burlot.p ascal(a)wanadoo.fr])
-dnl AC_CONFIG_SRCDIR([src/gms.c srcgms_gui.c])
+AC_INIT([geany-mini-script], [0.3], [burlot.p ascal(a)wanadoo.fr])
+dnl AC_CONFIG_SRCDIR([src/gms.c src/gms_gui.c])
AM_INIT_AUTOMAKE([1.9 foreign])
@@ -27,7 +27,7 @@
GTK_VERSION=`$PKG_CONFIG --modversion gtk+-2.0`
# i18n
-GETTEXT_PACKAGE=gms
+GETTEXT_PACKAGE=geany-mini-script
AC_SUBST(GETTEXT_PACKAGE)
AC_DEFINE_UNQUOTED(GETTEXT_PACKAGE,"$GETTEXT_PACKAGE", [Gettext package.])
Modified: trunk/geany-mini-script/po/de.po
===================================================================
--- trunk/geany-mini-script/po/de.po 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/po/de.po 2009-02-08 14:24:34 UTC (rev 462)
@@ -1,27 +1,29 @@
-# SOME DESCRIPTIVE TITLE.
-# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
-# This file is distributed under the same license as the PACKAGE package.
-# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
+# German translation of the geany-mini-script package.
+# Copyright (C) 2009 Pascal BURLOT
+# This file is distributed under the same license as the geany-mini-script package.
+# Enrico Tröger <enrico.troeger(a)uvena.de>, 2009.
#
+
msgid ""
msgstr ""
-"Project-Id-Version: PACKAGE VERSION\n"
+"Project-Id-Version: geany-mini-script 0.3\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2009-02-07 18:59+0100\n"
"PO-Revision-Date: 2009-02-07 19:01+0100\n"
-"Last-Translator: Burlot Pascal <prublot(at)users(dot)sourceforge(dot)net>\n"
-"Language-Team: LANGUAGE <LL(a)li.org>\n"
+"Last-Translator: Enrico Tröger <enrico.troeger(a)uvena.de>\n"
+"Language-Team: German <geany-i18n(a)uvena.de>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=utf-8\n"
"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=(n != 1);\n"
#: ../src/gms_gui.c:259
msgid "Load Mini-Script File"
-msgstr "Laden des mini Skriptes"
+msgstr "Mini-Skript laden"
#: ../src/gms_gui.c:317
msgid "Save Mini-Script File"
-msgstr "Schutz des mini Skriptes "
+msgstr "Mini-Skript speichern"
#: ../src/gms_gui.c:362
msgid ""
@@ -48,23 +50,23 @@
"Software Foundation; either version 2 of the License,\n"
"or (at your option) any later version."
msgstr ""
-"<b>GMS: Geany Minihandschrift-Filter Steck<b>\n"
-"Dies Steck ist Werkzeuge, um einen Handschrift-Filter auf anzuwenden:\n"
+"<b>GMS: Geany Mini-Skript Filter Plugin</b>\n"
+"Mit diesem Plugin können Sie Filter auf:\n"
" o die Text-Auswahl, \n"
" o das gegenwärtige Dokument, \n"
-" o alle Dokumente der gegenwärtigen Sitzung.\n"
-"\n"
-"Der Filtertyp kann sein:\n"
-" o Unix schält Handschrift, \n"
-" o perl Handschrift, \n"
-" o Python-Handschrift, \n"
+" o alle Dokumente der gegenwärtigen Sitzung\n"
+"anwenden.\n\n"
+"Der Filtertyp kann ein:\n"
+" o Unix Shell-Skript, \n"
+" o Perl Skript, \n"
+" o Python Skript, \n"
" o sed Befehle, \n"
-" o awk Handschrift.\n"
+" o awk Skript\n"
+"sein.\n\n"
+"<b>AUTHOR </b>\n"
+" Geschrieben von Pascal BURLOT (Dezember 2008)\n"
"\n"
-"<b>AUTOR <b>\n"
-" Geschrieben durch Pascal BURLOT (Dezember 2008)\n"
-"\n"
-"<b>LIZENZ:<b>\n"
+"<b>LIZENZ:</b>\n"
"This program is free software; you can redistribute \n"
"it and/or modify it under the terms of the GNU \n"
"General Public License as published by the Free \n"
@@ -73,37 +75,37 @@
#: ../src/gms_gui.c:452
msgid "Mini-Script Filter"
-msgstr "Filter mini Skript"
+msgstr "Mini-Skript Filter"
#: ../src/gms_gui.c:480
msgid "Clear the mini-script window"
-msgstr "Klären Sie das Minihandschrift-Fenster"
+msgstr "Leert das Skript-Fenster"
#: ../src/gms_gui.c:485
msgid "Load a mini-script into this window"
-msgstr "Laden Sie eine Minihandschrift in dieses Fenster"
+msgstr "Lädt eine Datei in das Skript-Fenster"
#: ../src/gms_gui.c:490
msgid "Save the mini-script into a file"
-msgstr "Sparen(Retten) Sie die Minihandschrift in eine Datei"
+msgstr "Speichert das Skript ab"
#: ../src/gms_gui.c:495
msgid "Display a information about the mini-script plugin"
-msgstr "Zeigen Sie eine Information über die Steck- Minihandschrift"
+msgstr "Zeigt Informationen über das Plugin"
#: ../src/gms_gui.c:503
msgid "select the mini-script type"
-msgstr "wählen Sie den Minihandschrift-Typ aus"
+msgstr "Wählen Sie den Skript-Typ aus"
#. Hbox : Radio bouttons for choosing the input:
#. selection/current document/all documents of the current session
#: ../src/gms_gui.c:534
msgid "filter input"
-msgstr "Eingangsfilter "
+msgstr "Eingabedaten für den Filter"
#: ../src/gms_gui.c:536
msgid "select the input of mini-script filter"
-msgstr "wählen Sie den Eingang des Minihandschrift-Filters aus"
+msgstr "Wählen Sie die Eingabedaten des Filters aus"
#: ../src/gms_gui.c:542
msgid "selection"
@@ -111,49 +113,49 @@
#: ../src/gms_gui.c:543
msgid "document"
-msgstr "dokument"
+msgstr "Dokument"
#: ../src/gms_gui.c:544
msgid "session"
-msgstr "session"
+msgstr "Sitzung"
#. Hbox : Radio bouttons for choosing the output:
#. current document/ or new document
#: ../src/gms_gui.c:553
msgid "filter output"
-msgstr " filtrede herausgenommen"
+msgstr "Filterausgabe"
#: ../src/gms_gui.c:555
msgid "select the output of mini-script filter"
-msgstr "wählen Sie die Produktion(Output) des Minihandschrift-Filters aus"
+msgstr "Wählen Sie die Ausgabe des Filters aus"
#: ../src/gms_gui.c:561
msgid "Current Doc."
-msgstr " übliche Dok."
+msgstr "Aktuelles Dokument"
#: ../src/gms_gui.c:562
msgid "New Doc."
-msgstr "neues Dok."
+msgstr "Neues Dokument"
#: ../src/gms_gui.c:788
msgid "script configuration"
-msgstr "Gestalt des Skriptes "
+msgstr "Skriptkonfiguration"
#. All plugins must set name, description, version and author.
#: ../src/gms.c:73
msgid "geany mini-script"
-msgstr "Ein kleines Skript für geany "
+msgstr "Geany Mini-Skript"
#: ../src/gms.c:73
msgid "GMS (Geany Mini-Script filter plugin)"
-msgstr "GMS (Geany Steck- Minihandschrift-Filter )"
+msgstr "GMS (Geany Mini-Skript-Filter)"
#: ../src/gms.c:74
msgid "Pascal BURLOT, a Geany user"
-msgstr "Pascal BURLOT, der Benutzer von Geany "
+msgstr "Pascal BURLOT, ein Geany-Benutzer"
#. Add an item to the Tools menu
#: ../src/gms.c:261
msgid "_Mini-Script"
-msgstr "_Mini-Script"
+msgstr "_Mini-Skript"
Modified: trunk/geany-mini-script/po/en.po
===================================================================
--- trunk/geany-mini-script/po/en.po 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/po/en.po 2009-02-08 14:24:34 UTC (rev 462)
@@ -1,16 +1,17 @@
-# SOME DESCRIPTIVE TITLE.
-# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
-# This file is distributed under the same license as the PACKAGE package.
-# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
+# English translation of the geany-mini-script package.
+# Copyright (C) 2009 Pascal BURLOT
+# This file is distributed under the same license as the geany-mini-script package.
+# Burlot Pascal <prublot(at)users(dot)sourceforge(dot)net>, 2009.
#
+
msgid ""
msgstr ""
-"Project-Id-Version: PACKAGE VERSION\n"
+"Project-Id-Version: geany-mini-script 0.3\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2009-02-07 18:59+0100\n"
"PO-Revision-Date: 2009-02-07 18:59+0100\n"
"Last-Translator: Burlot Pascal <prublot(at)users(dot)sourceforge(dot)net>\n"
-"Language-Team: LANGUAGE <LL(a)li.org>\n"
+"Language-Team: English <prublot(at)users(dot)sourceforge(dot)net>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=utf-8\n"
"Content-Transfer-Encoding: 8bit\n"
Modified: trunk/geany-mini-script/po/fr.po
===================================================================
--- trunk/geany-mini-script/po/fr.po 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/po/fr.po 2009-02-08 14:24:34 UTC (rev 462)
@@ -1,16 +1,17 @@
-# SOME DESCRIPTIVE TITLE.
-# Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
-# This file is distributed under the same license as the PACKAGE package.
-# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
+# French translation of the geany-mini-script package.
+# Copyright (C) 2009 Pascal BURLOT
+# This file is distributed under the same license as the geany-mini-script package.
+# Burlot Pascal <prublot(at)users(dot)sourceforge(dot)net>, 2009.
#
+
msgid ""
msgstr ""
-"Project-Id-Version: PACKAGE VERSION\n"
+"Project-Id-Version: geany-mini-script 0.3\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2009-02-07 18:59+0100\n"
"PO-Revision-Date: 2009-02-07 19:00+0100\n"
"Last-Translator: Burlot Pascal <prublot(at)users(dot)sourceforge(dot)net>\n"
-"Language-Team: LANGUAGE <LL(a)li.org>\n"
+"Language-Team: French <prublot(at)users(dot)sourceforge(dot)net>\n"
"MIME-Version: 1.0\n"
"Content-Type: text/plain; charset=utf-8\n"
"Content-Transfer-Encoding: 8bit\n"
@@ -58,7 +59,7 @@
" o tous les documents de la session courante.\n"
"\n"
"Le type du script peut être : \n"
-" o un script d'un shell UNIX, \n"
+" o un script shell UNIX, \n"
" o un script PERL, \n"
" o un script PYTHON, \n"
" o une liste de commandes SED,\n"
Modified: trunk/geany-mini-script/src/Makefile.am
===================================================================
--- trunk/geany-mini-script/src/Makefile.am 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/src/Makefile.am 2009-02-08 14:24:34 UTC (rev 462)
@@ -1,7 +1,7 @@
## Makefile.am -- Process this file with automake to produce Makefile.in
-lib_LTLIBRARIES = gms.la
-gms_la_SOURCES = gms.c gms_gui.c
-gms_la_LDFLAGS = -module -avoid-version
-gms_la_LIBADD = @GEANY_LIBS@
+lib_LTLIBRARIES = geany-mini-script.la
+geany_mini_script_la_SOURCES = gms.c gms_gui.c
+geany_mini_script_la_LDFLAGS = -module -avoid-version
+geany_mini_script_la_LIBADD = @GEANY_LIBS@
-AM_CPPFLAGS = -Wshadow @GEANY_CFLAGS@ -DLOCALEDIR=\""$(localedir)"\"
+AM_CPPFLAGS = @GEANY_CFLAGS@ -DLOCALEDIR=\""$(localedir)"\"
Modified: trunk/geany-mini-script/src/gms.c
===================================================================
--- trunk/geany-mini-script/src/gms.c 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/src/gms.c 2009-02-08 14:24:34 UTC (rev 462)
@@ -38,15 +38,19 @@
* - it will be loaded at next startup.
*/
+#include "geany.h"
+
/* headers */
#include <stdlib.h>
#include <glib.h>
#include <glib/gstdio.h>
-#include <libintl.h>
-#include <locale.h>
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
+
/* geany headers */
-#include "geany.h"
#include "support.h"
#include "plugindata.h"
#include "editor.h"
@@ -61,10 +65,12 @@
#include "gms_gui.h"
#include "gms_debug.h"
+
GeanyPlugin *geany_plugin;
GeanyData *geany_data;
GeanyFunctions *geany_functions;
+
/* Check that the running Geany supports the plugin API used below, and check
* for binary compatibility. */
PLUGIN_VERSION_CHECK(100)
@@ -246,12 +252,43 @@
}
+ /**
+ * \brief the function initializes the localization for the gms plugin
+ */
+static void locale_init(void)
+{
+#ifdef ENABLE_NLS
+ gchar *locale_dir = NULL;
+
+#ifdef HAVE_LOCALE_H
+ setlocale(LC_ALL, "");
+#endif
+
+#ifdef G_OS_WIN32
+ gchar *install_dir = g_win32_get_package_installation_directory("geany", NULL);
+ /* e.g. C:\Program Files\geany\lib\locale */
+ locale_dir = g_strconcat(install_dir, "\\share\\locale", NULL);
+ g_free(install_dir);
+#else
+ locale_dir = g_strdup(LOCALEDIR);
+#endif
+
+ bindtextdomain(GETTEXT_PACKAGE, locale_dir);
+ bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+ textdomain(GETTEXT_PACKAGE);
+ g_free(locale_dir);
+#endif
+}
+
+
/**
* \brief Called by Geany to initialize the plugin.
* \note data is the same as geany_data.
*/
void plugin_init(GeanyData *data)
{
+ locale_init();
+
gms_hnd = gms_new(geany->main_widgets->window,
data->interface_prefs->editor_font ,
data->editor_prefs->indentation->width
Modified: trunk/geany-mini-script/src/gms_gui.c
===================================================================
--- trunk/geany-mini-script/src/gms_gui.c 2009-02-07 22:29:50 UTC (rev 461)
+++ trunk/geany-mini-script/src/gms_gui.c 2009-02-08 14:24:34 UTC (rev 462)
@@ -25,8 +25,8 @@
* \file gms_gui.c
* \brief it is the graphical user interface of the geany miniscript plugin
*/
+#include "geany.h"
-#include <glib.h>
#include <glib/gstdio.h>
#include <glib/gprintf.h>
@@ -36,13 +36,13 @@
#include <sys/types.h>
#include <unistd.h>
-#include <libintl.h>
-#include <locale.h>
-
#include <pango/pango.h>
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
/* geany headers */
-#include "geany.h"
#include "support.h"
#include "plugindata.h"
#include "editor.h"
@@ -126,43 +126,36 @@
const gchar *label_script_cmd[GMS_NB_TYPE_SCRIPT] = {
"Shell", "Perl", "Python", "Sed", "Awk", "User" };
+///< \brief It's the information message about geany mini script
+const char *geany_info = "<b>GMS : Geany Mini-Script filter Plugin</b>\n"
+"This plugin is a tools to apply a script filter on :\n"
+" o the text selection,\n"
+" o the current document,\n"
+" o all documents of the current session.\n"
+"\n"
+"The filter type can be : \n"
+" o Unix shell script, \n"
+" o perl script, \n"
+" o python script, \n"
+" o sed commands,\n"
+" o awk script.\n"
+"\n"
+"<b>AUTHOR</b>\n"
+" Written by Pascal BURLOT (December,2008)\n"
+"\n"
+"<b>LICENSE:</b>\n"
+"This program is free software; you can redistribute\n"
+"it and/or modify it under the terms of the GNU \n"
+"General Public License as published by the Free\n"
+"Software Foundation; either version 2 of the License,\n"
+"or (at your option) any later version." ;
+
/*
* *****************************************************************************
* Local functions
*/
/**
- * \brief the function initializes the localization for the gms plugin
- */
-
-static void locale_init(void)
-{
-#ifdef ENABLE_NLS
- gchar *locale_dir = NULL;
-
-#ifdef HAVE_LOCALE_H
- setlocale(LC_ALL, "");
-#endif
-
-#ifdef G_OS_WIN32
- gchar *install_dir = g_win32_get_package_installation_directory("geany", NULL);
- /* e.g. C:\Program Files\geany\lib\locale */
- locale_dir = g_strconcat(install_dir, "\\share\\locale", NULL);
- g_free(install_dir);
-#else
- locale_dir = g_strdup(LOCALEDIR);
-#endif
-
- //g_print( "%s %s\n",GETTEXT_PACKAGE,locale_dir ) ;
-
- bindtextdomain(GETTEXT_PACKAGE, locale_dir);
- bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
- textdomain(GETTEXT_PACKAGE);
- g_free(locale_dir);
-#endif
-}
-
-/**
* \brief the function loads the preferences file
*/
static void load_prefs_file(
@@ -255,7 +248,6 @@
gms_private_t *this = GMS_PRIVATE(data) ;
GtkWidget *p_dialog ;
- locale_init();
p_dialog = gtk_file_chooser_dialog_new (_("Load Mini-Script File"),
GTK_WINDOW(this->mw) ,
GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -313,7 +305,6 @@
gms_private_t *this = GMS_PRIVATE(data) ;
GtkWidget *p_dialog ;
- locale_init();
p_dialog = gtk_file_chooser_dialog_new (_("Save Mini-Script File"),
GTK_WINDOW(this->mw) ,
GTK_FILE_CHOOSER_ACTION_SAVE,
@@ -354,39 +345,12 @@
)
{
gms_private_t *this = GMS_PRIVATE(data) ;
- gchar *info_msg ;
-
- locale_init();
- info_msg = _(
-"<b>GMS : Geany Mini-Script filter Plugin</b>\n"
-"This plugin is a tools to apply a script filter on :\n"
-" o the text selection,\n"
-" o the current document,\n"
-" o all documents of the current session.\n"
-"\n"
-"The filter type can be : \n"
-" o Unix shell script, \n"
-" o perl script, \n"
-" o python script, \n"
-" o sed commands,\n"
-" o awk script.\n"
-"\n"
-"<b>AUTHOR</b>\n"
-" Written by Pascal BURLOT (December,2008)\n"
-"\n"
-"<b>LICENSE:</b>\n"
-"This program is free software; you can redistribute\n"
-"it and/or modify it under the terms of the GNU \n"
-"General Public License as published by the Free\n"
-"Software Foundation; either version 2 of the License,\n"
-"or (at your option) any later version." ) ;
-
GtkWidget *dlg = gtk_message_dialog_new_with_markup( GTK_WINDOW(this->mw),
GTK_DIALOG_DESTROY_WITH_PARENT,
GTK_MESSAGE_INFO,
GTK_BUTTONS_CLOSE,
- _(info_msg),NULL );
+ _(geany_info),NULL );
gtk_dialog_run(GTK_DIALOG(dlg));
GMS_FREE_WIDGET(dlg);
@@ -421,8 +385,6 @@
{
gms_private_t *this = GMS_G_MALLOC0(gms_private_t,1);
- locale_init() ;
-
if ( this != NULL )
{
GtkBox *vb_dlg ; //!< vbox of dialog box
@@ -620,10 +582,6 @@
for ( i=0;i<GMS_NB_TYPE_SCRIPT ; i++ )
g_string_free(this->script_cmd[i] ,flag) ;
-
-
- gtk_object_unref( GTK_OBJECT(this->w.tips) );
- this->w.tips = NULL ;
GMS_G_FREE( this ) ;
}
@@ -783,7 +741,6 @@
GtkWidget *t_script ; //!< table for configuration script
GtkWidget *w ;
- locale_init() ;
vb_pref= gtk_vbox_new(FALSE, 6);
f_script = gtk_frame_new (_("script configuration") );
gtk_box_pack_start( GTK_BOX (vb_pref), f_script, FALSE, FALSE, 0);
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 460
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=460&view=rev
Author: yurand
Date: 2009-02-07 22:27:53 +0000 (Sat, 07 Feb 2009)
Log Message:
-----------
GeanyDoc: README update
Modified Paths:
--------------
trunk/geanydoc/README
Modified: trunk/geanydoc/README
===================================================================
--- trunk/geanydoc/README 2009-02-07 22:27:03 UTC (rev 459)
+++ trunk/geanydoc/README 2009-02-07 22:27:53 UTC (rev 460)
@@ -73,12 +73,32 @@
Download
========
-The current version is |(version)|, download it here http://users.cosmostv.by/yurand/geanydoc/geanydoc-0.3.tar.gz.
+The current version is:
+============= ================ ============================================================
+Geany Version GeanyDoc Version Download
+============= ================ ============================================================
+0.16 |(version)| http://users.cosmostv.by/yurand/geanydoc/geanydoc-0.4.tar.gz
+============= ================ ============================================================
+
Up to date source code can be downloaded here::
svn checkout http://geany-plugins.svn.sourceforge.net/svnroot/geany-plugins/trunk/geanyd…
+
+If you have old version of Geany installed you need old version of plugin as well. These versions of plugin
+are no longer supported and if you find bug in one of them, it won't be fixed unless you do it yourself.
+============= ================ ============================================================
+Geany Version GeanyDoc Version Download
+============= ================ ============================================================
+0.15 0.3 http://users.cosmostv.by/yurand/geanydoc/geanydoc-0.3.tar.gz
+
+0.14 0.2 http://users.cosmostv.by/yurand/geanydoc/geanydoc-0.2.tar.gz
+
+0.13 0.1 http://users.cosmostv.by/yurand/geanydoc/geanydoc-0.1.tar.gz
+============= ================ ============================================================
+
+
Gentoo
------
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
--- trunk/geanyvc/geanyvc.c 2009-02-09 14:56:49 UTC (rev 467)
+++ trunk/geanyvc/geanyvc.c 2009-02-10 22:55:07 UTC (rev 468)
@@ -1,7 +1,7 @@
/*
* geanyvc.c - Plugin to geany light IDE to work with vc
*
- * Copyright 2007, 2008 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
+ * Copyright 2007-2009 Frank Lanitz <frank(at)frank(dot)uvena(dot)de>
* Copyright 2007, 2008 Enrico Tröger <enrico.troeger(a)uvena.de>
* Copyright 2007 Nick Treleaven <nick.treleaven(a)btinternet.com>
* Copyright 2007, 2008 Yura Siamashka <yurand2(a)gmail.com>
@@ -1149,24 +1149,24 @@
renderer = gtk_cell_renderer_toggle_new();
g_signal_connect(renderer, "toggled", G_CALLBACK(commit_toggled), treeview);
- column = gtk_tree_view_column_new_with_attributes("Commit?",
+ column = gtk_tree_view_column_new_with_attributes(_("Commit Y/N"),
renderer, "active", COLUMN_COMMIT, NULL);
/* set this column to a fixed sizing (of 50 pixels) */
gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_FIXED);
- gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN(column), 70);
+ gtk_tree_view_column_set_fixed_width(GTK_TREE_VIEW_COLUMN(column), 80);
gtk_tree_view_append_column(treeview, column);
- /* column for bug numbers */
+ /* column for status */
renderer = gtk_cell_renderer_text_new();
- column = gtk_tree_view_column_new_with_attributes("Status",
+ column = gtk_tree_view_column_new_with_attributes(_("Status"),
renderer, "text", COLUMN_STATUS, NULL);
gtk_tree_view_column_set_sort_column_id(column, COLUMN_STATUS);
gtk_tree_view_append_column(treeview, column);
- /* column for severities */
+ /* column for path of file to commit */
renderer = gtk_cell_renderer_text_new();
- column = gtk_tree_view_column_new_with_attributes("Path",
+ column = gtk_tree_view_column_new_with_attributes(_("Path"),
renderer, "text", COLUMN_PATH, NULL);
gtk_tree_view_column_set_sort_column_id(column, COLUMN_PATH);
gtk_tree_view_append_column(treeview, column);
@@ -1149,24 +1149,24 @@
renderer, "active", COLUMN_COMMIT, NULL);
- /* set this column to a fixed sizing (of 50 pixels) */
+ /* set this column to a fixed sizing (of 80 pixels) */
gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_FIXED);
Modified: trunk/geanyvc/po/de.po
===================================================================